/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the examples of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:BSD$
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
** $QT_END_LICENSE$
**
****************************************************************************/

import QtQuick 1.0
import QtMobility.sensors 1.1
import RotationExample 1.0

Board {
    width: 100
    height: 62
    id: screen

    property real speedX: 0
    property real speedY: 0

    RotationSensor {
        id: sensor
    }

    Image {
        id: puck
        source: "qt-logo.png"
    }

    Timer {
        id: timer
        repeat: true
        interval: 50

        onTriggered: {
            var reading = sensor.reading

            if ((puck.y > 0 || reading.x > 0) &&
                    (puck.y < screen.height - puck.height || reading.x < 0))
                speedX += (reading.x / 10)

            if ((puck.x > 0 || reading.y > 0) &&
                    (puck.x < screen.width - puck.width || reading.y < 0))
                speedY += (reading.y / 10)

            var updateSpeedX = Math.max(Math.abs(speedX) -
                                        Math.abs(reading.x / 3), 0)
            var updateSpeedY = Math.max(Math.abs(speedY) -
                                        Math.abs(reading.y / 3), 0)

            if (puck.x < 0) {
                puck.x = 0
                speedY = updateSpeedY
            } else if (puck.x + puck.width > screen.width) {
                puck.x = screen.width - puck.width
                speedY = -updateSpeedY
            }
            if (puck.y < 0) {
                puck.y = 0
                speedX = updateSpeedX
            } else if (puck.y + puck.height > screen.height) {
                puck.y = screen.height - puck.height
                speedX = -updateSpeedX
            }

            puck.y += speedX
            puck.x += speedY
        }
    }

    Text {
        anchors.centerIn: parent
        opacity: hasSensor ? 0.0 : 1.0
        font.pointSize: 12
        text: "Rotation sensor not available"
    }

    Component.onCompleted: {
        if (hasSensor) {
            puck.x = 100
            puck.y = 100
            sensor.start()
            timer.start()
        }
    }
}
