/****************************************************************************
**
** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the documentation of Qt. It was originally
** published as part of Qt Quarterly.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

import QtQuick 1.0
import QtMobility.location 1.1

Item {
    width: 400
    height: 400

    Map {
        id: map
        anchors.fill: parent
        zoomLevel: zoomSlider.value
        center: Coordinate {
            latitude: 51
            longitude: 4
        }
        plugin: Plugin {
            name: "nokia"
        }
    }

    MouseArea {
        id: area
        anchors.fill: parent
        property real startX: 0
        property real startY: 0

        onPressed: {
            startX = mouse.x
            startY = mouse.y
        }

        onPositionChanged: {
            var dx = mouse.x - startX
            var dy = mouse.y - startY
            var pos = map.toScreenPosition(map.center)
            pos.x -= dx
            pos.y -= dy
            map.center = map.toCoordinate(pos)
            startX = mouse.x
            startY = mouse.y
        }
    }

    Slider {
        id: zoomSlider
        anchors.top: parent.top
        anchors.topMargin: 5
        anchors.left: parent.left
        anchors.leftMargin: 5
        anchors.bottom: parent.verticalCenter
        anchors.bottomMargin: 5
        width: 16
        z: 1

        minimumValue: map.minimumZoomLevel
        maximumValue: map.maximumZoomLevel
        value: 10
    }

    MapTypeButtons {
        anchors.top: parent.top
        anchors.topMargin: 5
        anchors.right: parent.right
        anchors.rightMargin: 5

        onClicked: map.mapType = mapType
    }
}
