#!/usr/bin/env python

#############################################################################
##
## Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
## All rights reserved.
## Contact: Nokia Corporation (qt-info@nokia.com)
##
## This file is part of the documentation of Qt. It was originally
## published as part of Qt Quarterly.
##
## $QT_BEGIN_LICENSE:LGPL$
## Commercial Usage
## Licensees holding valid Qt Commercial licenses may use this file in
## accordance with the Qt Commercial License Agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and Nokia.
##
## GNU Lesser General Public License Usage
## Alternatively, this file may be used under the terms of the GNU Lesser
## General Public License version 2.1 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL included in the
## packaging of this file.  Please review the following information to
## ensure the GNU Lesser General Public License version 2.1 requirements
## will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
##
## In addition, as a special exception, Nokia gives you certain additional
## rights.  These rights are described in the Nokia Qt LGPL Exception
## version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3.0 as published by the Free Software
## Foundation and appearing in the file LICENSE.GPL included in the
## packaging of this file.  Please review the following information to
## ensure the GNU General Public License version 3.0 requirements will be
## met: http://www.gnu.org/copyleft/gpl.html.
##
## If you have questions regarding the use of this file, please contact
## Nokia at qt-info@nokia.com.
## $QT_END_LICENSE$
##
#############################################################################

import sys
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from PyQt4.QtSvg import *

def paintZoom(painter):

    painter.setPen(QPen(QColor(64, 64, 64)))
    painter.setBrush(QBrush(frameGradient))
    painter.drawPolygon(QPolygon([QPoint(50, 60), QPoint(85, 95),
                                  QPoint(95, 85), QPoint(60, 50)]))
    
    painter.drawEllipse(5, 5, 80, 80)
    painter.setBrush(QBrush(lensGradient))
    painter.drawEllipse(QRectF(7.5, 7.5, 75, 75))
    
    painter.setPen(QPen(Qt.NoPen))
    painter.setBrush(QBrush(Qt.black))

def paintZoomOut(painter):

    paintZoom(painter)
    painter.drawRect(QRectF(25, 40, 40, 10))

def paintZoomIn(painter):

    paintZoom(painter)
    painter.drawRect(QRectF(40, 25, 10, 40))
    painter.drawRect(QRectF(25, 40, 40, 10))

def paintPointer(painter):

    painter.setPen(QPen(QColor(64, 64, 64)))
    painter.setBrush(QBrush(Qt.white))
    
    painter.drawPolygon(QPolygon([QPoint(22, 5), QPoint(20, 75), QPoint(40, 60),
                                  QPoint(55, 95), QPoint(75, 85), QPoint(55, 54),
                                  QPoint(79, 47)]))

def paintIcon(function, file_name):

    image = QImage(128, 128, QImage.Format_ARGB32)
    image.fill(qRgba(0, 0, 0, 0))
    
    painter = QPainter()
    painter.begin(image)
    painter.setRenderHint(QPainter.Antialiasing)
    painter.scale(1.28, 1.28)
    function(painter)
    painter.end()
    
    image.save(file_name)


app = QApplication(sys.argv)

svg = QSvgGenerator()
svg.setFileName("zoomin.svg")
svg.setSize(QSize(100, 100))
svg.setViewBox(QRect(0, 0, 100, 100))
svg.setTitle("Zoom in icon")
svg.setDescription("Icon used for a button that allows the user to zoom in on "
                   "an area in a map.")

frameGradient = QLinearGradient(0, 0, 0, 100)
frameGradient.setColorAt(0.0, QColor(64, 64, 64))
frameGradient.setColorAt(0.5, QColor(128, 128, 128))
frameGradient.setColorAt(1.0, QColor(92, 92, 92))

lensGradient = QRadialGradient(47.5, 47.5, 42, 47.5, 47.5)
lensGradient.setColorAt(0.0, QColor(255, 255, 255))
lensGradient.setColorAt(1.0, QColor(160, 160, 160))

paintIcon(paintZoomIn, "zoomin.png")
paintIcon(paintZoomOut, "zoomout.png")
paintIcon(paintPointer, "selectmode.png")

#painter = QPainter()
#painter.begin(svg)
#paintZoomIn(painter)
#painter.end()
